==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/eo.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ŝargo de antaŭrigardo...",
    "Saved" : "Konservita",
    "Admin" : "Administranto",
    "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
    "Name cannot be empty" : "Nomo ne povas mapleni",
    "The given name is too long" : "Tiu nomo tro longas",
    "The given web address is too long" : "Tiu TTT-adreso tro longas",
    "The given legal notice address is too long" : "Tiu adreso pri leĝa regularo tro longas",
    "The given privacy policy address is too long" : "Tiu adreso pri privateca regularo tro longas",
    "The given slogan is too long" : "Tiu frapfrazo tro longas",
    "The given color is invalid" : "Tiu koloro ne validas",
    "The file was uploaded" : "La dosiero alŝutiĝis.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon MAX_FILE_SIZE, kiu estas difinita en la HTML-formularo",
    "The file was only partially uploaded" : "La dosiero alŝutiĝis nur parte",
    "No file was uploaded" : "Neniu dosiero alŝutiĝis.",
    "Missing a temporary folder" : "Mankas provizora dosierujo",
    "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
    "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
    "No file uploaded" : "Neniu dosiero alŝutiĝis",
    "Unsupported image type" : "Nesubtenata bildotipo",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vi jam uzas propran etoson. Agordoj de la aplikaĵo „Etosoj“ povus esti anstataŭigitaj de ĝi.",
    "Theming" : "Etosoj",
    "Legal notice" : "Leĝa regularo",
    "Privacy policy" : "Privateca regularo",
    "Adjust the Nextcloud theme" : "Modifi la Nextcloud-etoson",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Etosoj ebligas facilan ŝanĝon en la fasado de via servilo kaj de subtenataj klientoj. Tion vidos ĉiuj uzantoj.",
    "Name" : "Nomo",
    "Reset to default" : "Restarigi al defaŭltaj agordoj",
    "Web link" : "Reta ligilo",
    "https://…" : "https://…",
    "Slogan" : "Frapfrazo",
    "Color" : "Koloro",
    "Logo" : "Emblemo",
    "Upload new logo" : "Alŝuti novan emblemon",
    "Login image" : "Ensaluta bildo",
    "Upload new login background" : "Alŝuti novan ensalutan fonan bildon",
    "Remove background image" : "Forigi fonan bildon",
    "Advanced options" : "Detalaj agordoj",
    "Legal notice link" : "Ligilo al leĝa regularo",
    "Privacy policy link" : "Ligilo al privateca regularo",
    "Header logo" : "Paĝokapa emblemo",
    "Upload new header logo" : "Alŝuti novan paĝokapan emblemon",
    "Favicon" : "Retpaĝsimbolo",
    "Upload new favicon" : "Alŝuti novan retpaĝsimbolon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalu la PHP-modulon „Imagemagick“ kun SVG-subteno por aŭtomate krei retpaĝsimbolon, kiu devenos de la alŝutita emblemo kaj koloro."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/eo.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ŝargo de antaŭrigardo...",
    "Admin" : "Administranto",
    "Saved" : "Konservita",
    "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
    "Name cannot be empty" : "Nomo ne povas mapleni",
    "The given name is too long" : "Tiu nomo tro longas",
    "The given web address is too long" : "Tiu TTT-adreso tro longas",
    "The given web address is not a valid URL" : "Tiu TTT-adreso ne estas valida retadreso",
    "The given legal notice address is too long" : "Tiu adreso pri leĝa regularo tro longas",
    "The given legal notice address is not a valid URL" : "La adreso al leĝa regularo ne estas valida retadreso",
    "The given privacy policy address is too long" : "Tiu adreso pri privateca regularo tro longas",
    "The given privacy policy address is not a valid URL" : "La adreso al privateca regularo ne estas valida retadreso",
    "The given slogan is too long" : "Tiu frapfrazo tro longas",
    "The given color is invalid" : "Tiu koloro ne validas",
    "The file was uploaded" : "La dosiero alŝutiĝis.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon MAX_FILE_SIZE, kiu estas difinita en la HTML-formularo",
    "The file was only partially uploaded" : "La dosiero alŝutiĝis nur parte",
    "No file was uploaded" : "Neniu dosiero alŝutiĝis.",
    "Missing a temporary folder" : "Mankas provizora dosierujo",
    "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
    "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
    "No file uploaded" : "Neniu dosiero alŝutiĝis",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vi jam uzas propran etoson. Agordoj de la aplikaĵo „Etosoj“ povus esti anstataŭigitaj de ĝi.",
    "Theming" : "Etosoj",
    "Dark theme" : "Malhela etoso",
    "Dyslexia font" : "Tiparo por limigi vortblindecon",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic estas tiparo kreita por malpliigi legajn erarojn kaŭzitajn de vortblindeco (medicine „disleksio“).",
    "High contrast mode" : "Altkontrasta reĝimo",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Altkontrasta reĝimo, kiu faciligas vian navigadon. Vida kvalito malpliiĝos, sed klareco pliiĝos.",
    "Legal notice" : "Leĝa regularo",
    "Privacy policy" : "Privateca regularo",
    "Adjust the Nextcloud theme" : "Modifi la Nextcloud-etoson",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Open documentation" : "Malfermi la dokumentaron",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Etosoj ebligas facilan ŝanĝon en la fasado de via servilo kaj de subtenataj klientoj. Tion vidos ĉiuj uzantoj.",
    "Name" : "Nomo",
    "Reset to default" : "Restarigi al defaŭltaj agordoj",
    "Web link" : "Reta ligilo",
    "https://…" : "https://…",
    "Slogan" : "Frapfrazo",
    "Color" : "Koloro",
    "Logo" : "Emblemo",
    "Upload new logo" : "Alŝuti novan emblemon",
    "Login image" : "Ensaluta bildo",
    "Upload new login background" : "Alŝuti novan ensalutan fonan bildon",
    "Remove background image" : "Forigi fonan bildon",
    "Advanced options" : "Detalaj agordoj",
    "Legal notice link" : "Ligilo al leĝa regularo",
    "Privacy policy link" : "Ligilo al privateca regularo",
    "Header logo" : "Paĝokapa emblemo",
    "Upload new header logo" : "Alŝuti novan paĝokapan emblemon",
    "Favicon" : "Retpaĝsimbolo",
    "Upload new favicon" : "Alŝuti novan retpaĝsimbolon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalu la PHP-modulon „Imagemagick“ kun SVG-subteno por aŭtomate krei retpaĝsimbolon, kiu devenos de la alŝutita emblemo kaj koloro."
},
"nplurals=2; plural=(n != 1);");
